@@ -1,7 +1,7 @@
 package Data::Verifier;
 use Moose;
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 use Data::Verifier::Field;
 use Data::Verifier::Filters;
@@ -288,6 +288,13 @@ It should be noted that if you choose to make a param a C<Str> then validation
 will fail if multiple values are provided.  To allow multiple values you
 must use an C<ArrayRef[Str]>.
 
+=head2 Stops on First Failure
+
+Data::Verifier stops checking a field (not all, just the failed one) if it
+fails any of it's constraints. Consult the Execution Order below to ascertain
+the order.  For example, if a field exceeds it's max length then it will not
+be checked against it's type constraint.
+
 =head2 Serialization
 
 Data::Verifier uses L<MooseX::Storage> to allow serialization of
@@ -498,6 +505,8 @@ J. Shirley
 
 Stevan Little
 
+George Hartzell
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009 Cold Hard Code, LLC
